TokenizationModuleInputData class

Constructors

TokenizationModuleInputData({required String clientApplicationKey, required String title, required String subtitle, required Amount amount, required SavePaymentMethod savePaymentMethod, required String shopId, String? moneyAuthClientId, HostParameters? hostParameters, String? gatewayId, TokenizationSettings tokenizationSettings = const TokenizationSettings(), TestModeSettings? testModeSettings, String? returnUrl, bool isLoggingEnabled = false, String? userPhoneNumber, CustomizationSettings customizationSettings = const CustomizationSettings(), String? applicationScheme, String? customerId, String? lang, GooglePayParameters googlePayParameters = const GooglePayParameters(), bool googlePayTestEnvironment = false})

Properties

amount ↔ Amount
getter/setter pair
applicationScheme ↔ String?
getter/setter pair
clientApplicationKey ↔ String
getter/setter pair
customerId ↔ String?
getter/setter pair
customizationSettings ↔ CustomizationSettings
getter/setter pair
gatewayId ↔ String?
getter/setter pair
googlePayParameters ↔ GooglePayParameters
getter/setter pair
googlePayTestEnvironment ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostParameters ↔ HostParameters?
getter/setter pair
isLoggingEnabled ↔ bool
getter/setter pair
lang ↔ String?
getter/setter pair
moneyAuthClientId ↔ String?
getter/setter pair
returnUrl ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savePaymentMethod ↔ SavePaymentMethod
getter/setter pair
shopId ↔ String
getter/setter pair
subtitle ↔ String
getter/setter pair
testModeSettings ↔ TestModeSettings?
getter/setter pair
title ↔ String
getter/setter pair
tokenizationSettings ↔ TokenizationSettings
getter/setter pair
userPhoneNumber ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited