HostParameters class

Constructors

HostParameters(String host, String paymentAuthorizationHost, String authHost, String configHost)
HostParameters.fromJson(Map<String, dynamic> json)
factory

Properties

authHost ↔ String
getter/setter pair
configHost ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String
getter/setter pair
paymentAuthorizationHost ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited